@@ -1,5 +1,5 @@
 import numpy as np
-from wwprocess.PlotSchema import Schema
+from wwprocess.plots.PlotSchema import PlotSchema
 
 """
 将output目录下的一个试验对应的一个文件夹封装为一个对象
@@ -108,9 +108,9 @@ class AET:  # AeroElasticTest
                     self.calcAvgInAllWindSpeeds('accel')
         # 绘图
         if alignment == 'single':
-            plt = Schema('single')
+            plt = PlotSchema('single')
         elif alignment == 'double':
-            plt = Schema('double')
+            plt = PlotSchema('double')
         fig, ax = plt.subplots()
 
         if sigType == 'disp':
